<div align="center">
<h2>SynopGround: A Large-Scale Dataset for Multi-Paragraph Video Grounding from TV Dramas and Synopses</h2>

[[**arXiv**](https://arxiv.org/abs/2408.01669)] [[**Website**](https://synopground.github.io/)]
</div>

This is the official repository that maintains the dataset and code for the paper **SynopGround: A Large-Scale Dataset for Multi-Paragraph Video Grounding from TV Dramas and Synopses** accepted at ACM MM 2024.

<p align="center"><img width="850" src="assets/img.png"></p>

# ⭐️ Highlights

- 🔥 SynopGround is a large-scale dataset for Multi-Paragraph Video Grounding (MPVG), which is a new direction involving both long-form video inputs and long paragraph queries for dense video grounding.

- 🔥 We collect episodes from popular TV dramas of various genres up to a total duration of 2800+ hours. For each video, professional human-written synopses are maunally annotated with precise temporal starting and ending boundaries, using each synopsis paragraph as language query.

- 🔥 Our dataset has ~100 words per query and ~43 minutes per video on average, which brings unique challenges in terms of modeling long-term contexts of both video and language modalities.

- 🔥 A novel baseline method called Local-Global Multimodal Reasoner (LGMR) is specifically designed as the first attempt for tackling MPVG and serves as a good starting point for future research.

# 🔨 Installation
Note: PyTorch 1.8.1 is recommended for CUDA version <= 12.0 and PyTorch 1.9.0 for CUDA version > 12.0
```
git clone https://github.com/SynopGround/SynopGround.git
cd SynopGround

conda create -n synopground python=3.8
conda activate synopground

pip install torch==1.8.1+cu111 torchvision==0.9.1+cu111 torchaudio==0.8.1 -f https://download.pytorch.org/whl/torch_stable.html
pip install pyyaml tqdm
```

# 💻 Dataset Preparation

Download all the pre-extracted features from [[**OneDrive**](https://1drv.ms/f/c/53106d24c92b4d11/EuS4C7qurgtCnJO9v0Vz_SgB9wIs6gSuAKICOUodvu7TEw?e=0o4quP)], including the video features `video_slowfast.zip`, `video_clip.zip`, `video_ocr.zip`, and query features `text_roberta.zip`. Then, place all zipped files under `/data/features` and unzip. You should download and prepare the dataset in the following structure:
```
SynopGround
├── ···
├── configs
├── data
│   ├── annotations
│   │   ├── train.json
│   │   ├── val.json
│   │   └── test.json
│   ├── features
│   │   ├── video_slowfast
│   │   ├── video_clip
│   │   └── video_ocr
|   |   └── text_roberta
├── datasets
├── models
└── ···
```

# 🚀 Quick Start
By default, we recommend using 4 GPUs with 24GB or 32GB memory for training, such as NVIDIA GeForce RTX 3090 and NVIDIA Tesla V100. For inference, 1 GPU with 24GB memory or less would be fine.

## 1. Training
When you have prepared the dataset, then start training by running the command:
```
python -u -m torch.distributed.launch \
--nproc_per_node 4 \
--master_port 1234 \
scripts/train.py \
--exp_id LGMR
```

## 2. Inference
Once the training is finished, run the following command for model inference. Remember to specify CKPT_PATH by your actual path to the model checkpoint, which is automatically saved in `/results/exp_id`.
```
python -u scripts/inference.py --ckpt CKPT_PATH inference.py
```

We also provide a checkpoint [[**here**](https://1drv.ms/f/c/53106d24c92b4d11/EpDGluPuxFBPo60qeUCehRkBiVA75wm8iszw74mM_-escQ?e=J79gij)] for our baseline model trained on SynopGround. After download it and specify CKPT_PATH for inference, you are expected to obtain the performance below:
<table>
  <tr>
    <th>R@0.1</th>
    <th>R@0.3</th>
    <th>R@0.5</th>
    <th>R@0.7</th>
    <th>mIoU</th>
  </tr>
  <tr>
    <td align="center">83.25</td>
    <td align="center">69.98</td>
    <td align="center">47.99</td>
    <td align="center">22.41</td>
    <td align="center">45.30</td>
  </tr>
</table>

# 📝 Citation
If you find this project is helpful to your research, please consider citing our paper:
```
@inproceedings{tan2024synopground,
author={Tan, Chaolei and Lin, Zihang and Pu, Junfu and Qi, Zhongang and Pei, Wei-Yi and Qu, Zhi and Wang, Yexin and Shan, Ying and Zheng, Wei-Shi and Hu, Jian-Fang},
title={SynopGround: A Large-Scale Dataset for Multi-Paragraph Video Grounding from TV Dramas and Synopses},
booktitle={ACM MM},
year={2024}
}
```

# ❤️ Acknowledgement
Our implementation is partially based on [DETR](https://github.com/facebookresearch/detr). We sincerely thank the authors for their awesome contributions.

# ✅ License
The dataset and code are intended and licensed for research use only. The dataset assets of annotations and features are under [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/) license at [data/LICENSE](./data/LICENSE). All the code is under [MIT](https://opensource.org/licenses/MIT) license at [LICENSE](./LICENSE).