# Copyright (c) THL A29 Limited, a Tencent company. All rights reserved
# Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved

'''
DETR Decoder class

Modified from DETR (https://github.com/facebookresearch/detr)
'''

from torch import nn
from .transformer import TransformerDecoderLayer, TransformerDecoder

class DETRDecoder(nn.Module):

    def __init__(self, num_layers=1, d_model=512, nhead=8, dim_feedforward=2048, dropout=0.1):
        super(DETRDecoder, self).__init__()
        decoder_layer = TransformerDecoderLayer(d_model=d_model,
                                                nhead=nhead,
                                                dim_feedforward=dim_feedforward,
                                                dropout=dropout,
                                                activation='relu')
        decoder_norm = nn.LayerNorm(d_model)
        self.decoder = TransformerDecoder(decoder_layer, num_layers=num_layers, norm=decoder_norm, return_intermediate=True)

    def forward(self, query, query_mask, memory, memory_mask,
                pos, query_pos, return_weights=False):
        # out: [nlayer, query_len, b, c]
        out = self.decoder(tgt=query, memory=memory, pos=pos,
                           tgt_key_padding_mask=query_mask,      
                           memory_key_padding_mask=memory_mask,
                           query_pos=query_pos, 
                           return_weights=return_weights)

        if return_weights:
            out, att_weights = out
            # out: [nlayer, b, query_len, c], att_weights: [nlayer, b, query_len, memory_len]
            return out.transpose(1, 2).contiguous(), att_weights
        
        return out.transpose(1, 2).contiguous() # [nlayer, b, query_len, c]
